==> hpijs-1.1.tar.gz: hpijs-1.1/dj970_maps3.cpp <==
/*****************************************************************************\
  dj970_maps3.cpp : Color maps for DJ970

  Copyright (c) 1996 - 2002, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

APDK_BEGIN_NAMESPACE

unsigned long ulMapBROADWAY_Draft_KCMY[ 9*9*9 ]=
{
1802205183UL,   22740362UL,    5832524UL,    5635892UL,    5570340UL,    5308188UL, 
   5308180UL,    5504778UL,    5504768UL, 4278239136UL,      65446UL,    4194132UL, 
   5308210UL,    5373728UL,    5308182UL,    5504784UL,    5504776UL,    5504768UL, 
4278498896UL, 1862336354UL,      65388UL,    2621242UL,    4128540UL,    4718348UL, 
   5570304UL,    5177088UL,    5111552UL, 4278758188UL, 4278317636UL, 1291910980UL, 
     65356UL,    1638182UL,    2817798UL,    3866368UL,    4325120UL,    4652288UL, 
4279018260UL, 4278239016UL, 2717974318UL,  872480562UL,      65330UL,    1113876UL, 
   2162432UL,    3407616UL,    4128512UL, 4279147522UL, 4278239002UL, 4009819936UL, 
1778450206UL,  604045088UL,      65310UL,     851206UL,    2227968UL,    3079936UL, 
4278688260UL, 4278563846UL, 4278244882UL, 2936078096UL, 1375797010UL,  469827346UL, 
  16842514UL,     851712UL,    2096896UL, 4278425088UL, 4278428928UL, 4278237184UL, 
4093705984UL, 2097217286UL, 1073806598UL,  385941254UL,      65286UL,     917248UL, 
4278222592UL, 4278226176UL, 4278232832UL, 4244692736UL, 3288399616UL, 1812004608UL, 
 922812160UL,  335609088UL,      65280UL, 3724477142UL,   16718478UL,   33550676UL, 
  13303598UL,    9830180UL,    7798550UL,    6553360UL,    6553352UL,    6160128UL, 
4282864474UL, 2206438326UL,    6029146UL,    5963570UL,    5766942UL,    5701394UL, 
   5766922UL,    5832448UL,    5570304UL, 4280056368UL, 4278842230UL,  320208754UL, 
  20249912UL,    4718358UL,    5373702UL,    5439232UL,    5439232UL,    5308160UL, 
4279667474UL, 4278433338UL, 1644429122UL,  370278210UL,   69271328UL,    3145472UL, 
   4324608UL,    4783872UL,    5046016UL, 4279405826UL, 4278628890UL, 3137404712UL, 
1174732586UL,  420805918UL,  237043456UL,    2686720UL,    3735296UL,    4390656UL, 
4279077120UL, 4278628358UL, 4278253844UL, 2047147790UL, 1091370762UL,  437649158UL, 
 118947584UL,    2490112UL,    3342080UL, 4278619648UL, 4278428416UL, 4278241024UL, 
3120627460UL, 1745288960UL,  822869760UL,  302907136UL,     917248UL,    2490112UL, 
4278223616UL, 4278226432UL, 4278235904UL, 4278255360UL, 2499870464UL, 1392574208UL, 
 637861632UL,  134545152UL,    1048320UL, 4278220544UL, 4278222592UL, 4278230528UL, 
4278243072UL, 3170957056UL, 2097217280UL, 1040252672UL,  419495680UL,      65280UL, 
4292804720UL,  503119998UL,   16718158UL,   16746540UL,   16771616UL,   29556490UL, 
  11271936UL,    9502464UL,    8650496UL, 4285475388UL, 2885626240UL,  167729236UL, 
  16758306UL,   15335178UL,   11664640UL,    9699072UL,    7732992UL,    7339776UL, 
4282796800UL, 4282866746UL, 2374868552UL,  528613152UL,   88866564UL,    6618880UL, 
   6225664UL,    6225664UL,    6618880UL, 4280441088UL, 4280251412UL, 3962958640UL, 
1195375408UL,  492044036UL,    5046016UL,    5504768UL,    5766912UL,    5832448UL, 
4279527168UL, 4279598848UL, 4246063890UL, 2082471702UL,  909049610UL,  321847040UL, 
   3407616UL,    4390656UL,    4914944UL, 4278938880UL, 4278812928UL, 4278698244UL, 
3071737090UL, 1595604736UL,  656408320UL,  153026304UL,    3012352UL,    3865344UL, 
4278481408UL, 4278222336UL, 4278233856UL, 3892707072UL, 2215182080UL,  973930240UL, 
 403700480UL,    1106176UL,    2346496UL, 4278217984UL, 4278220032UL, 4278228992UL, 
4144027904UL, 2600525056UL, 1543564288UL,  671150080UL,  134278144UL,    1032960UL, 
4278218496UL, 4278221824UL, 4278227200UL, 3959468800UL, 2751510016UL, 1996537088UL, 
1107352832UL,  503374848UL,      58368UL, 4291364662UL, 1845428294UL,  150929488UL, 
  16717104UL,   16605464UL,   16756486UL,   16774656UL,   12975872UL,   10223360UL, 
4287437850UL, 4293789518UL,  553586254UL,   33501734UL,   16739844UL,   16761856UL, 
  15924992UL,   12844800UL,   10157824UL, 4283576576UL, 4251463964UL, 2830980654UL, 
 820802084UL,  184527360UL,   16776960UL,   12779264UL,   10223360UL,    9240320UL, 
4280889344UL, 4281876992UL, 4284576524UL, 2324339712UL,  864667136UL,  108199680UL, 
   7339264UL,    7077632UL,    7143168UL, 4279648512UL, 4279782656UL, 4247287040UL, 
2957291776UL, 1363851520UL,  440777984UL,    4711424UL,    5896960UL,    6094592UL, 
4278996992UL, 4278933248UL, 4279268864UL, 3458382080UL, 1864676864UL,  791131904UL, 
 153467392UL,    3259648UL,    4052224UL, 4278408960UL, 4278212864UL, 4278221056UL, 
3893081600UL, 2249111296UL, 1057993728UL,  403812352UL,    1223168UL,    2403072UL, 
4278213632UL, 4278216960UL, 4278222592UL, 3825248000UL, 2449517056UL, 1459662336UL, 
 654355968UL,   83928064UL,    1023488UL, 4278216192UL, 4278217984UL, 4278223104UL, 
3523252992UL, 2600507392UL, 1845533440UL, 1057006592UL,  503358720UL,      41216UL, 
4290644754UL, 3221159980UL,  905904176UL,   16712244UL,   16584982UL,   16731654UL, 
  16744960UL,   16631808UL,   16514816UL, 4287894786UL, 4258923556UL, 1325335340UL, 
 134023468UL,   16721664UL,   16735232UL,   16747264UL,   16764416UL,   15793920UL, 
4284029696UL, 4286520328UL, 3976146960UL, 1174352154UL,  352274944UL,   16742912UL, 
  16755456UL,   16507904UL,   13299712UL, 4281671424UL, 4282459904UL, 4286072320UL, 
2610913280UL,  933718016UL,   10648320UL,   11446272UL,   11255552UL,   10407424UL, 
4279835904UL, 4280101120UL, 4281418240UL, 3075696896UL, 1566403328UL,  508855296UL, 
   5348864UL,    6338816UL,    6733568UL, 4279053568UL, 4279055104UL, 4279519488UL, 
3274142208UL, 1965914624UL,  841974016UL,  153847552UL,    3644160UL,    4369664UL, 
4278467328UL, 4278337024UL, 4278539264UL, 3574364160UL, 2249424384UL, 1108706048UL, 
 420840960UL,    1410816UL,    2592768UL, 4244652800UL, 4244656128UL, 4278214656UL, 
3640686336UL, 2415950592UL, 1392540928UL,  671121664UL,   67140096UL,    1016064UL, 
4278212096UL, 4278213632UL, 4278216960UL, 3271585536UL, 2516612352UL, 1761637632UL, 
1056996096UL,  536903936UL,      30720UL, 4289858560UL, 3841916954UL, 1610547224UL, 
 436011032UL,   16712726UL,   16583942UL,   16727040UL,   16738816UL,   16751872UL, 
4287892736UL, 4258334214UL, 1862205460UL,  587007244UL,   66915842UL,   16719616UL, 
  16730624UL,   16742400UL,   16621568UL, 4284419840UL, 4286648064UL, 4294186498UL, 
1727994624UL,  503258880UL,   16591616UL,   16736000UL,   16747776UL,   15970560UL, 
4282126848UL, 4282717184UL, 4285997312UL, 2628005888UL, 1101869568UL,  212940544UL, 
  12346112UL,   12554240UL,   11838464UL, 4280161792UL, 4280555776UL, 4282656768UL, 
2975807744UL, 1667644160UL,  560676352UL,    7427072UL,    8683008UL,    8623360UL, 
4279243776UL, 4279310592UL, 4279969024UL, 3526310912UL, 2050178816UL,  960052480UL, 
 204690432UL,    3763968UL,    4753664UL, 4278656000UL, 4278590976UL, 4278790400UL, 
3641786880UL, 2199208960UL, 1159286016UL,  421090304UL,    1726720UL,    2780160UL, 
4278200064UL, 4278202368UL, 4278205952UL, 3523235072UL, 2298497536UL, 1459967488UL, 
 704927488UL,  100684544UL,    1137664UL, 4278206208UL, 4244654080UL, 4026552576UL, 
3103805696UL, 2466272256UL, 1711298304UL, 1006655744UL,  520117248UL,      22272UL, 
4289136640UL, 4293591052UL, 2399076362UL,  973013004UL,  268369930UL,   16712710UL, 
  16713984UL,   16723200UL,   16734464UL, 4287760128UL, 4290708224UL, 2835283968UL, 
1090322432UL,  234815488UL,   16714240UL,   16717824UL,   16726272UL,   16737792UL, 
4285073408UL, 4286645504UL, 4292411392UL, 1979647232UL,  687802368UL,   16714752UL, 
  16589824UL,   16729856UL,   16741888UL, 4282648832UL, 4283238400UL, 4286122752UL, 
2678526464UL, 1219367680UL,  364254720UL,   12789760UL,   13782272UL,   13268736UL, 
4280552704UL, 4280814592UL, 4282716928UL, 2925730560UL, 1701584128UL,  712252928UL, 
   7808000UL,    9389824UL,   10055168UL, 4279504640UL, 4279636224UL, 4280489984UL, 
3056935168UL, 2000232960UL,  993797120UL,  222177280UL,    4930048UL,    6117632UL, 
4278848768UL, 4278784000UL, 4279113472UL, 3709346816UL, 2216371712UL, 1193093120UL, 
 555820032UL,    2110464UL,    2901248UL, 4278326016UL, 4278195200UL, 4278197504UL, 
3640666112UL, 2248157440UL, 1392782592UL,  738800384UL,  117912576UL,    1194240UL, 
4278198528UL, 4278200576UL, 4026544896UL, 2952803328UL, 2365601280UL, 1660958208UL, 
 973092864UL,  486553600UL,      13824UL, 4288742656UL, 4292608000UL, 3254714368UL, 
1526661120UL,  603783168UL,  201261056UL,   16711936UL,   16713216UL,   16720128UL, 
4287628032UL, 4289986560UL, 3640590336UL, 1828651008UL,  721354752UL,  201261056UL, 
  16713216UL,   16715776UL,   16722176UL, 4285923840UL, 4287168512UL, 4292018176UL, 
2533294080UL, 1140785152UL,  301793280UL,   16582912UL,   16717568UL,   16724736UL, 
4282974976UL, 4283367424UL, 4286513152UL, 2812608512UL, 1521483776UL,  481361920UL, 
  12322560UL,   14228992UL,   14236160UL, 4280812544UL, 4247454208UL, 4282909440UL, 
2909340416UL, 1718551808UL,  796395008UL,  108922624UL,    9379328UL,   10566400UL, 
4279633664UL, 4246276096UL, 4280813824UL, 3006794496UL, 1916537856UL, 1010699264UL, 
 323226880UL,    5315328UL,    6632960UL, 4278979072UL, 4279044608UL, 4279438592UL, 
3021737728UL, 2065764096UL, 1143214080UL,  539431168UL,    2692608UL,    3353344UL, 
4278453760UL, 4278323200UL, 4278389504UL, 3641119232UL, 2450002432UL, 1409946624UL, 
 722146560UL,  252645120UL,    1385216UL, 4278193408UL, 4278194944UL, 4076870144UL, 
3003128576UL, 2298486272UL, 1593843456UL,  905977344UL,  436216064UL,       8448UL, 
4292214784UL, 4292804608UL, 3707699200UL, 2097086464UL, 1090453504UL,  503119872UL, 
 218038272UL,   67043328UL,   16711680UL, 4287627264UL, 4255580160UL, 4076797952UL, 
2399076352UL, 1358888960UL,  603914240UL,  251592704UL,   16711680UL,   16711680UL, 
4286316544UL, 4286578688UL, 4291493888UL, 3019833344UL, 1845428224UL,  788463616UL, 
 285016064UL,   16711680UL,   16711680UL, 4283367424UL, 4284678144UL, 4287102976UL, 
3064594432UL, 2058747904UL,  985268224UL,  364838912UL,   13762560UL,   15466496UL, 
4281401344UL, 4282449920UL, 4284088320UL, 3010723840UL, 2004353024UL, 1065418752UL, 
 411303936UL,    9437184UL,   10747904UL, 4279762944UL, 4280221696UL, 4281466880UL, 
2872836096UL, 2000945152UL, 1095237632UL,  525205504UL,    5505024UL,    6881280UL, 
4278845440UL, 4279238656UL, 4279762944UL, 2871066624UL, 2015625216UL, 1143406592UL, 
 589889536UL,   86835200UL,    3735552UL, 4278190080UL, 4278190080UL, 4278386688UL, 
3053912064UL, 2097807360UL, 1208811520UL,  688848896UL,  185729024UL,    1835008UL, 
4278190080UL, 4278190080UL, 4278190080UL, 3154116608UL, 2365587456UL, 1610612736UL, 
 905969664UL,  452984832UL,          0UL, 
};

APDK_END_NAMESPACE

#if 0
/*** Version Info ***/ 
     1020102927,       // Date (UTC Format) (Local Time : Mon Apr 29 10:55:27 AM  
     1,                       /* Resource Type - color map      */ 
     0,                       /* Footer Type  0/1 (rel/debug    */ 
     kHPBroadway,                       /* Product Name                   */ 
     kHPPlain,                       /* media Name                     */ 
     kHPDraftMode,                       /* Quality Name                   */ 
     5000,                       /* Color Mapper Tool Version      */ 
     1,                       /* Map Version                    */ 
     kHP9Cubed,                       /* Map Type                       */ 
     0,                       /* BrkPt Table Resource Number    */ 
     kHP3x3,                       /* Color Resolution               */ 
     kHP3x3                        /* Black Resolution               */ 
#endif

==> hpijs-1.7.1.tar.gz: hpijs-1.7.1/dj970_maps3.cpp <==
/*****************************************************************************\
  dj970_maps3.cpp : Color maps for DJ970

  Copyright (c) 1996 - 2002, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

APDK_BEGIN_NAMESPACE

uint32_t ulMapBROADWAY_Draft_KCMY[ 9*9*9 ]=
{
1802205183UL,   22740362UL,    5832524UL,    5635892UL,    5570340UL,    5308188UL,
   5308180UL,    5504778UL,    5504768UL, 4278239136UL,      65446UL,    4194132UL,
   5308210UL,    5373728UL,    5308182UL,    5504784UL,    5504776UL,    5504768UL,
4278498896UL, 1862336354UL,      65388UL,    2621242UL,    4128540UL,    4718348UL,
   5570304UL,    5177088UL,    5111552UL, 4278758188UL, 4278317636UL, 1291910980UL,
     65356UL,    1638182UL,    2817798UL,    3866368UL,    4325120UL,    4652288UL,
4279018260UL, 4278239016UL, 2717974318UL,  872480562UL,      65330UL,    1113876UL,
   2162432UL,    3407616UL,    4128512UL, 4279147522UL, 4278239002UL, 4009819936UL,
1778450206UL,  604045088UL,      65310UL,     851206UL,    2227968UL,    3079936UL,
4278688260UL, 4278563846UL, 4278244882UL, 2936078096UL, 1375797010UL,  469827346UL,
  16842514UL,     851712UL,    2096896UL, 4278425088UL, 4278428928UL, 4278237184UL,
4093705984UL, 2097217286UL, 1073806598UL,  385941254UL,      65286UL,     917248UL,
4278222592UL, 4278226176UL, 4278232832UL, 4244692736UL, 3288399616UL, 1812004608UL,
 922812160UL,  335609088UL,      65280UL, 3724477142UL,   16718478UL,   33550676UL,
  13303598UL,    9830180UL,    7798550UL,    6553360UL,    6553352UL,    6160128UL,
4282864474UL, 2206438326UL,    6029146UL,    5963570UL,    5766942UL,    5701394UL,
   5766922UL,    5832448UL,    5570304UL, 4280056368UL, 4278842230UL,  320208754UL,
  20249912UL,    4718358UL,    5373702UL,    5439232UL,    5439232UL,    5308160UL,
4279667474UL, 4278433338UL, 1644429122UL,  370278210UL,   69271328UL,    3145472UL,
   4324608UL,    4783872UL,    5046016UL, 4279405826UL, 4278628890UL, 3137404712UL,
1174732586UL,  420805918UL,  237043456UL,    2686720UL,    3735296UL,    4390656UL,
4279077120UL, 4278628358UL, 4278253844UL, 2047147790UL, 1091370762UL,  437649158UL,
 118947584UL,    2490112UL,    3342080UL, 4278619648UL, 4278428416UL, 4278241024UL,
3120627460UL, 1745288960UL,  822869760UL,  302907136UL,     917248UL,    2490112UL,
4278223616UL, 4278226432UL, 4278235904UL, 4278255360UL, 2499870464UL, 1392574208UL,
 637861632UL,  134545152UL,    1048320UL, 4278220544UL, 4278222592UL, 4278230528UL,
4278243072UL, 3170957056UL, 2097217280UL, 1040252672UL,  419495680UL,      65280UL,
4292804720UL,  503119998UL,   16718158UL,   16746540UL,   16771616UL,   29556490UL,
  11271936UL,    9502464UL,    8650496UL, 4285475388UL, 2885626240UL,  167729236UL,
  16758306UL,   15335178UL,   11664640UL,    9699072UL,    7732992UL,    7339776UL,
4282796800UL, 4282866746UL, 2374868552UL,  528613152UL,   88866564UL,    6618880UL,
   6225664UL,    6225664UL,    6618880UL, 4280441088UL, 4280251412UL, 3962958640UL,
1195375408UL,  492044036UL,    5046016UL,    5504768UL,    5766912UL,    5832448UL,
4279527168UL, 4279598848UL, 4246063890UL, 2082471702UL,  909049610UL,  321847040UL,
   3407616UL,    4390656UL,    4914944UL, 4278938880UL, 4278812928UL, 4278698244UL,
3071737090UL, 1595604736UL,  656408320UL,  153026304UL,    3012352UL,    3865344UL,
4278481408UL, 4278222336UL, 4278233856UL, 3892707072UL, 2215182080UL,  973930240UL,
 403700480UL,    1106176UL,    2346496UL, 4278217984UL, 4278220032UL, 4278228992UL,
4144027904UL, 2600525056UL, 1543564288UL,  671150080UL,  134278144UL,    1032960UL,
4278218496UL, 4278221824UL, 4278227200UL, 3959468800UL, 2751510016UL, 1996537088UL,
1107352832UL,  503374848UL,      58368UL, 4291364662UL, 1845428294UL,  150929488UL,
  16717104UL,   16605464UL,   16756486UL,   16774656UL,   12975872UL,   10223360UL,
4287437850UL, 4293789518UL,  553586254UL,   33501734UL,   16739844UL,   16761856UL,
  15924992UL,   12844800UL,   10157824UL, 4283576576UL, 4251463964UL, 2830980654UL,
 820802084UL,  184527360UL,   16776960UL,   12779264UL,   10223360UL,    9240320UL,
4280889344UL, 4281876992UL, 4284576524UL, 2324339712UL,  864667136UL,  108199680UL,
   7339264UL,    7077632UL,    7143168UL, 4279648512UL, 4279782656UL, 4247287040UL,
2957291776UL, 1363851520UL,  440777984UL,    4711424UL,    5896960UL,    6094592UL,
4278996992UL, 4278933248UL, 4279268864UL, 3458382080UL, 1864676864UL,  791131904UL,
 153467392UL,    3259648UL,    4052224UL, 4278408960UL, 4278212864UL, 4278221056UL,
3893081600UL, 2249111296UL, 1057993728UL,  403812352UL,    1223168UL,    2403072UL,
4278213632UL, 4278216960UL, 4278222592UL, 3825248000UL, 2449517056UL, 1459662336UL,
 654355968UL,   83928064UL,    1023488UL, 4278216192UL, 4278217984UL, 4278223104UL,
3523252992UL, 2600507392UL, 1845533440UL, 1057006592UL,  503358720UL,      41216UL,
4290644754UL, 3221159980UL,  905904176UL,   16712244UL,   16584982UL,   16731654UL,
  16744960UL,   16631808UL,   16514816UL, 4287894786UL, 4258923556UL, 1325335340UL,
 134023468UL,   16721664UL,   16735232UL,   16747264UL,   16764416UL,   15793920UL,
4284029696UL, 4286520328UL, 3976146960UL, 1174352154UL,  352274944UL,   16742912UL,
  16755456UL,   16507904UL,   13299712UL, 4281671424UL, 4282459904UL, 4286072320UL,
2610913280UL,  933718016UL,   10648320UL,   11446272UL,   11255552UL,   10407424UL,
4279835904UL, 4280101120UL, 4281418240UL, 3075696896UL, 1566403328UL,  508855296UL,
   5348864UL,    6338816UL,    6733568UL, 4279053568UL, 4279055104UL, 4279519488UL,
3274142208UL, 1965914624UL,  841974016UL,  153847552UL,    3644160UL,    4369664UL,
4278467328UL, 4278337024UL, 4278539264UL, 3574364160UL, 2249424384UL, 1108706048UL,
 420840960UL,    1410816UL,    2592768UL, 4244652800UL, 4244656128UL, 4278214656UL,
3640686336UL, 2415950592UL, 1392540928UL,  671121664UL,   67140096UL,    1016064UL,
4278212096UL, 4278213632UL, 4278216960UL, 3271585536UL, 2516612352UL, 1761637632UL,
1056996096UL,  536903936UL,      30720UL, 4289858560UL, 3841916954UL, 1610547224UL,
 436011032UL,   16712726UL,   16583942UL,   16727040UL,   16738816UL,   16751872UL,
4287892736UL, 4258334214UL, 1862205460UL,  587007244UL,   66915842UL,   16719616UL,
  16730624UL,   16742400UL,   16621568UL, 4284419840UL, 4286648064UL, 4294186498UL,
1727994624UL,  503258880UL,   16591616UL,   16736000UL,   16747776UL,   15970560UL,
4282126848UL, 4282717184UL, 4285997312UL, 2628005888UL, 1101869568UL,  212940544UL,
  12346112UL,   12554240UL,   11838464UL, 4280161792UL, 4280555776UL, 4282656768UL,
2975807744UL, 1667644160UL,  560676352UL,    7427072UL,    8683008UL,    8623360UL,
4279243776UL, 4279310592UL, 4279969024UL, 3526310912UL, 2050178816UL,  960052480UL,
 204690432UL,    3763968UL,    4753664UL, 4278656000UL, 4278590976UL, 4278790400UL,
3641786880UL, 2199208960UL, 1159286016UL,  421090304UL,    1726720UL,    2780160UL,
4278200064UL, 4278202368UL, 4278205952UL, 3523235072UL, 2298497536UL, 1459967488UL,
 704927488UL,  100684544UL,    1137664UL, 4278206208UL, 4244654080UL, 4026552576UL,
3103805696UL, 2466272256UL, 1711298304UL, 1006655744UL,  520117248UL,      22272UL,
4289136640UL, 4293591052UL, 2399076362UL,  973013004UL,  268369930UL,   16712710UL,
  16713984UL,   16723200UL,   16734464UL, 4287760128UL, 4290708224UL, 2835283968UL,
1090322432UL,  234815488UL,   16714240UL,   16717824UL,   16726272UL,   16737792UL,
4285073408UL, 4286645504UL, 4292411392UL, 1979647232UL,  687802368UL,   16714752UL,
  16589824UL,   16729856UL,   16741888UL, 4282648832UL, 4283238400UL, 4286122752UL,
2678526464UL, 1219367680UL,  364254720UL,   12789760UL,   13782272UL,   13268736UL,
4280552704UL, 4280814592UL, 4282716928UL, 2925730560UL, 1701584128UL,  712252928UL,
   7808000UL,    9389824UL,   10055168UL, 4279504640UL, 4279636224UL, 4280489984UL,
3056935168UL, 2000232960UL,  993797120UL,  222177280UL,    4930048UL,    6117632UL,
4278848768UL, 4278784000UL, 4279113472UL, 3709346816UL, 2216371712UL, 1193093120UL,
 555820032UL,    2110464UL,    2901248UL, 4278326016UL, 4278195200UL, 4278197504UL,
3640666112UL, 2248157440UL, 1392782592UL,  738800384UL,  117912576UL,    1194240UL,
4278198528UL, 4278200576UL, 4026544896UL, 2952803328UL, 2365601280UL, 1660958208UL,
 973092864UL,  486553600UL,      13824UL, 4288742656UL, 4292608000UL, 3254714368UL,
1526661120UL,  603783168UL,  201261056UL,   16711936UL,   16713216UL,   16720128UL,
4287628032UL, 4289986560UL, 3640590336UL, 1828651008UL,  721354752UL,  201261056UL,
  16713216UL,   16715776UL,   16722176UL, 4285923840UL, 4287168512UL, 4292018176UL,
2533294080UL, 1140785152UL,  301793280UL,   16582912UL,   16717568UL,   16724736UL,
4282974976UL, 4283367424UL, 4286513152UL, 2812608512UL, 1521483776UL,  481361920UL,
  12322560UL,   14228992UL,   14236160UL, 4280812544UL, 4247454208UL, 4282909440UL,
2909340416UL, 1718551808UL,  796395008UL,  108922624UL,    9379328UL,   10566400UL,
4279633664UL, 4246276096UL, 4280813824UL, 3006794496UL, 1916537856UL, 1010699264UL,
 323226880UL,    5315328UL,    6632960UL, 4278979072UL, 4279044608UL, 4279438592UL,
3021737728UL, 2065764096UL, 1143214080UL,  539431168UL,    2692608UL,    3353344UL,
4278453760UL, 4278323200UL, 4278389504UL, 3641119232UL, 2450002432UL, 1409946624UL,
 722146560UL,  252645120UL,    1385216UL, 4278193408UL, 4278194944UL, 4076870144UL,
3003128576UL, 2298486272UL, 1593843456UL,  905977344UL,  436216064UL,       8448UL,
4292214784UL, 4292804608UL, 3707699200UL, 2097086464UL, 1090453504UL,  503119872UL,
 218038272UL,   67043328UL,   16711680UL, 4287627264UL, 4255580160UL, 4076797952UL,
2399076352UL, 1358888960UL,  603914240UL,  251592704UL,   16711680UL,   16711680UL,
4286316544UL, 4286578688UL, 4291493888UL, 3019833344UL, 1845428224UL,  788463616UL,
 285016064UL,   16711680UL,   16711680UL, 4283367424UL, 4284678144UL, 4287102976UL,
3064594432UL, 2058747904UL,  985268224UL,  364838912UL,   13762560UL,   15466496UL,
4281401344UL, 4282449920UL, 4284088320UL, 3010723840UL, 2004353024UL, 1065418752UL,
 411303936UL,    9437184UL,   10747904UL, 4279762944UL, 4280221696UL, 4281466880UL,
2872836096UL, 2000945152UL, 1095237632UL,  525205504UL,    5505024UL,    6881280UL,
4278845440UL, 4279238656UL, 4279762944UL, 2871066624UL, 2015625216UL, 1143406592UL,
 589889536UL,   86835200UL,    3735552UL, 4278190080UL, 4278190080UL, 4278386688UL,
3053912064UL, 2097807360UL, 1208811520UL,  688848896UL,  185729024UL,    1835008UL,
4278190080UL, 4278190080UL, 4278190080UL, 3154116608UL, 2365587456UL, 1610612736UL,
 905969664UL,  452984832UL,          0UL,
};

APDK_END_NAMESPACE

#if 0
/*** Version Info ***/
     1020102927,       // Date (UTC Format) (Local Time : Mon Apr 29 10:55:27 AM
     1,                       /* Resource Type - color map      */
     0,                       /* Footer Type  0/1 (rel/debug    */
     kHPBroadway,                       /* Product Name                   */
     kHPPlain,                       /* media Name                     */
     kHPDraftMode,                       /* Quality Name                   */
     5000,                       /* Color Mapper Tool Version      */
     1,                       /* Map Version                    */
     kHP9Cubed,                       /* Map Type                       */
     0,                       /* BrkPt Table Resource Number    */
     kHP3x3,                       /* Color Resolution               */
     kHP3x3                        /* Black Resolution               */
#endif
